@@ -2,7 +2,7 @@
 
    This file is part of the LogWatcher tool.
 
-   Copyright (C) 2002 Artur Robert Czechowski
+   Copyright (C) 2002-2009 Artur Robert Czechowski
 
    The LogWatcher is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -25,7 +25,7 @@
  */
 
 /*
- * $Id: defaults.h,v 1.8 2003/04/07 14:51:41 arturcz Exp $
+ * $Id: defaults.h,v 1.10 2009/03/23 21:15:34 arturcz Exp $
  * $Source: /cvsroot/lwatch/files/src/defaults.h,v $
  */
 
@@ -34,6 +34,10 @@
 #define YES 1
 #define NO 0
 
+#define RULE_DEFAULT 0
+#define RULE_EXIT 1
+#define RULE_CONTINUE 2
+
 #define DEF_DATE_COLOR CYAN
 #define DEF_HOST_COLOR MAGENTA
 #define DEF_SERV_COLOR BLUE
@@ -42,3 +46,4 @@
 #define DEF_IN_FILE INPUTFILE
 #define DEF_OUT_FILE "-"
 #define DEF_CREATE_FIFO YES
+#define DEF_ACTION_RULE RULE_CONTINUE
